from src.tictactoe_marlene import Tictactoe


def main():
    """ Main with new game obj and call start"""
    game = Tictactoe()
    game.start()


if __name__ == "__main__":
    main()


